aboutsummaryrefslogtreecommitdiff
path: root/google/ads/googleads/v1/resources/product_bidding_category_constant.proto
diff options
context:
space:
mode:
Diffstat (limited to 'google/ads/googleads/v1/resources/product_bidding_category_constant.proto')
-rw-r--r--google/ads/googleads/v1/resources/product_bidding_category_constant.proto4
1 files changed, 2 insertions, 2 deletions
diff --git a/google/ads/googleads/v1/resources/product_bidding_category_constant.proto b/google/ads/googleads/v1/resources/product_bidding_category_constant.proto
index 75bc9dc27..b4f4f90ec 100644
--- a/google/ads/googleads/v1/resources/product_bidding_category_constant.proto
+++ b/google/ads/googleads/v1/resources/product_bidding_category_constant.proto
@@ -41,12 +41,12 @@ message ProductBiddingCategoryConstant {
pattern: "productBiddingCategoryConstants/{product_bidding_category_constant}"
};
// Immutable. The resource name of the product bidding category.
// Product bidding category resource names have the form:
//
// `productBiddingCategoryConstants/{country_code}~{level}~{id}`
string resource_name = 1 [
- (google.api.field_behavior) = IMMUTABLE,
+ (google.api.field_behavior) = OUTPUT_ONLY,
(google.api.resource_reference) = {
type: "googleads.googleapis.com/ProductBiddingCategoryConstant"
}
@@ -41,12 +41,12 @@ message ProductBiddingCategoryConstant {
pattern: "productBiddingCategoryConstants/{product_bidding_category_constant}"
};
- // Immutable. The resource name of the product bidding category.
+ // Output only. The resource name of the product bidding category.
// Product bidding category resource names have the form:
//